@@ -37,9 +37,8 @@ class GithubBackend(OAuthBackend):
 
     def get_user_details(self, response):
         """Return user details from Github account"""
-	print response
         return {USERNAME: response.get('login'),
-                'email': response.get('email'),
+                'email': response.get('email') or '',
                 'first_name': response.get('name')}
 
 class GithubAuth(BaseOAuth):
